cli

package
v1.73.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 23, 2025 License: Apache-2.0 Imports: 26 Imported by: 2

Documentation

Overview

Package cli was originally just fortio_main.go at the root of fortio.org/fortio now moved here it can be customized and reused in variants of fortio like fortiotel (fortio with opentelemetry).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FortioMain

func FortioMain(hook bincommon.FortioHook) int

Types

This section is empty.

Jump to