Documentation
¶
Overview ¶
Package cli was originally just fortio_main.go at the root of fortio.org/fortio now moved here it can be customized and reused in variants of fortio like fortiotel (fortio with opentelemetry).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FortioMain ¶
func FortioMain(hook bincommon.FortioHook) int
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.